==> flink-1.16.2-src.tgz: flink-1.16.2/flink-libraries/flink-cep/src/main/java/org/apache/flink/cep/nfa/sharedbuffer/SharedBufferNodeSerializerSnapshotV2.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.cep.nfa.sharedbuffer;

import org.apache.flink.api.common.typeutils.CompositeTypeSerializerSnapshot;
import org.apache.flink.api.common.typeutils.TypeSerializer;

/** Serializer configuration snapshot for compatibility and format evolution. */
public final class SharedBufferNodeSerializerSnapshotV2
        extends CompositeTypeSerializerSnapshot<SharedBufferNode, SharedBufferNodeSerializer> {

    private static final int VERSION = 1;

    public SharedBufferNodeSerializerSnapshotV2() {
        super(SharedBufferNodeSerializer.class);
    }

    public SharedBufferNodeSerializerSnapshotV2(
            SharedBufferNodeSerializer sharedBufferNodeSerializer) {
        super(sharedBufferNodeSerializer);
    }

    @Override
    protected int getCurrentOuterSnapshotVersion() {
        return VERSION;
    }

    @Override
    @SuppressWarnings("unchecked")
    protected SharedBufferNodeSerializer createOuterSerializerWithNestedSerializers(
            TypeSerializer<?>[] nestedSerializers) {
        return new SharedBufferNodeSerializer(
                (TypeSerializer<SharedBufferEdge>) nestedSerializers[0]);
    }

    @Override
    protected TypeSerializer<?>[] getNestedSerializers(SharedBufferNodeSerializer outerSerializer) {
        return new TypeSerializer<?>[] {outerSerializer.getEdgeSerializer()};
    }
}

==> flink-1.20.2-src.tgz: flink-1.20.2/flink-libraries/flink-cep/src/main/java/org/apache/flink/cep/nfa/sharedbuffer/SharedBufferNodeSerializerSnapshotV2.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.cep.nfa.sharedbuffer;

import org.apache.flink.api.common.typeutils.CompositeTypeSerializerSnapshot;
import org.apache.flink.api.common.typeutils.TypeSerializer;

/** Serializer configuration snapshot for compatibility and format evolution. */
public final class SharedBufferNodeSerializerSnapshotV2
        extends CompositeTypeSerializerSnapshot<SharedBufferNode, SharedBufferNodeSerializer> {

    private static final int VERSION = 1;

    public SharedBufferNodeSerializerSnapshotV2() {}

    public SharedBufferNodeSerializerSnapshotV2(
            SharedBufferNodeSerializer sharedBufferNodeSerializer) {
        super(sharedBufferNodeSerializer);
    }

    @Override
    protected int getCurrentOuterSnapshotVersion() {
        return VERSION;
    }

    @Override
    @SuppressWarnings("unchecked")
    protected SharedBufferNodeSerializer createOuterSerializerWithNestedSerializers(
            TypeSerializer<?>[] nestedSerializers) {
        return new SharedBufferNodeSerializer(
                (TypeSerializer<SharedBufferEdge>) nestedSerializers[0]);
    }

    @Override
    protected TypeSerializer<?>[] getNestedSerializers(SharedBufferNodeSerializer outerSerializer) {
        return new TypeSerializer<?>[] {outerSerializer.getEdgeSerializer()};
    }
}
